<template>
  <a-card
    :bordered="false"
    :class="'cust-erp-sub-tab'"
  >
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form
        layout="inline"
        @keyup.enter.native="searchQuery"
      >
        <a-row :gutter="24">
        </a-row>
      </a-form>
    </div>
    <a-button
      @click="handleAdd"
      type="primary"
      icon="plus"
      v-if="specialtyMaintenanceStandardSelectionRows.length == 1 "
      :disabled="addDisableStatus"
    >新增</a-button>
    <div>

      <a-table
        ref="table"
        size="middle"
        bordered
        rowKey="id"
        :scroll="{x:true}"
        :columns="columns"
        :dataSource="dataSource"
        :pagination="ipagination"
        :loading="loading"
        @change="handleTableChange"
      >
        <span
          slot="action"
          slot-scope="text, record"
        >
          <a-popconfirm
            title="确定删除吗?"
            @confirm="() => handleDelete(record.id)"
          >
            <a v-if="!addDisableStatus">删除</a>
          </a-popconfirm>
        </span>
      </a-table>
    </div>
    <maintenance-standard-planning-material-modal
      ref="modalForm"
      @ok="modalFormOk"
      :mainId="maintenanceStandardId"
    ></maintenance-standard-planning-material-modal>
  </a-card>
</template>

<script>
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import { getAction, deleteAction } from '@/api/manage'
import Tooltip from 'ant-design-vue/es/tooltip'
import MaintenanceStandardPlanningMaterialModal from './MaintenanceStandardPlanningMaterialModal'

export default {
  name: "MaintenanceStandardPlanningMaterial",
  components: {
    Tooltip,
    MaintenanceStandardPlanningMaterialModal
  },
  mixins: [JeecgListMixin],
  props: {
    maintenanceStandardId: {
      type: String,
      default: '-1',
      required: false
    },
    addDisableStatus:{
      type:Boolean,
      required:false,
      default:true,
    }
  },
  mounted() {
    this.$bus.$on('specialtyMaintenanceStandardSelectionRows', (data) => {
      this.specialtyMaintenanceStandardSelectionRows = data
    })
  },
  watch: {
    maintenanceStandardId: {
      immediate: true,
      handler(val) {
        if (!this.maintenanceStandardId) {
          this.clearList()
        } else {
          this.queryParam['maintenanceStandardId'] = val;
          this.queryParam['delFlag'] = 0;
          this.loadData(1);
        }
      }
    }
  },
  data() {
    return {
      specialtyMaintenanceStandardSelectionRows: [],
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 100,
          align: "center",
          customRender: function (t, r, index) {
            return parseInt(index) + 1;
          }
        },
        {
          title: '备件编号',
          align: "center",
          dataIndex: 'num',

        },
        {
          title: '备件名称',
          align: "center",
          dataIndex: 'name',

        },
        {
          title: '规格',
          align: "center",
          dataIndex: 'specification',
        },
        {
          title: '型号',
          align: "center",
          dataIndex: 'model',
        },
        {
          title: '单位',
          align: "center",
          dataIndex: 'unitName',
        },
        {
          title: '数量',
          align: "center",
          dataIndex: 'quantity',
        },
        {
          title: '操作',
          align: 'center',
          dataIndex: 'action',
          scopedSlots: {
            customRender: 'action'
          },
        }
      ],
      url: {
        list: "/eam/maintenanceStandardPlanningMaterial/getMaintenanceStandardPlanningMaterialList",
        delete: "/eam/maintenanceStandardPlanningMaterial/delete",
      },
    }
  },

  methods: {
    handleAdd: function () {
      this.$refs.modalForm.add();
      this.$refs.modalForm.title = "计划用料";
      this.$refs.modalForm.disableSubmit = false;
      this.$refs.modalForm.maintenanceStandardId = this.maintenanceStandardId
    },

    handleDelete: function (id) {
      if (!this.url.delete) {
        this.$message.error("请设置url.delete属性!")
        return
      }
      var that = this;
      deleteAction(that.url.delete, { id: id }).then((res) => {
        if (res.success) {
          //重新计算分页问题
          that.reCalculatePage(1)
          that.$message.success(res.message);
          that.loadData();
          that.alterFlag = new Date();
        } else {
          that.$message.warning(res.message);
        }
      });
    },
    clearList() {
      this.dataSource = []
      this.selectedRowKeys = []
      this.ipagination.current = 1
    },
    loadData(arg) {
      if (!this.url.list) {
        this.$message.error("请设置url.list属性!")
        return
      }
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1;
      }
      var params = this.getQueryParams();//查询条件
      this.loading = true;
      // this.originTargetKeys = [];
      getAction(this.url.list, params).then((res) => {
        if (res.success) {
          this.dataSource = res.result.records || res.result;

          if (res.result.total) {
            this.ipagination.total = res.result.total;
          } else {
            this.ipagination.total = 0;
          }
          //update-end---author:zhangyafei    Date:20201118  for：适配不分页的数据列表------------
        } else {
          this.$message.warning(res.message)
        }
      }).finally(() => {
        this.loading = false
      })
    },
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>
